@@ -3,7 +3,7 @@ use warnings;
 
 package JMAP::Tester;
 # ABSTRACT: a JMAP client made for testing JMAP servers
-$JMAP::Tester::VERSION = '0.023';
+$JMAP::Tester::VERSION = '0.024';
 use Moo;
 
 use Crypt::Misc qw(decode_b64u encode_b64u);
@@ -193,6 +193,46 @@ has default_arguments => (
   default => sub {  {}  },
 );
 
+#pod =attr accounts
+#pod
+#pod This is an arrayref of accounts, provided by the client session object.  This
+#pod method will return a list when accounts have been configured.
+#pod
+#pod =cut
+
+has _accounts => (
+  is        => 'rw',
+  init_arg  => undef,
+  predicate => '_has_accounts',
+);
+
+sub accounts {
+  return unless $_[0]->_has_accounts;
+  return @{ $_[0]->_accounts }
+}
+
+#pod =method primary_account_for
+#pod
+#pod   my $account_id = $tester->primary_account_for($using);
+#pod
+#pod This returns the primary accountId to be used for the given capability, or
+#pod undef if none is available.  This is only useful if the tester has been
+#pod configured from a client session.
+#pod
+#pod =cut
+
+has _primary_accounts => (
+  is        => 'rw',
+  init_arg  => undef,
+  predicate => '_has_primary_accounts',
+);
+
+sub primary_account_for {
+  my ($self, $using) = @_;
+  return unless $self->_has_primary_accounts;
+  return $self->_primary_accounts->{ $using };
+}
+
 #pod =method request
 #pod
 #pod   my $result = $jtest->request([
@@ -219,6 +259,9 @@ has default_arguments => (
 #pod failure objects may exist in the future.  Successful requests return
 #pod L<JMAP::Tester::Response> objects.
 #pod
+#pod Before the JMAP request is made, each triple is passed to a method called
+#pod C<munge_method_triple>, which can tweak the method however it likes.
+#pod
 #pod =cut
 
 sub request {
@@ -263,6 +306,11 @@ sub request {
 
     $copy->[1] = \%arg;
 
+    # Originally, I had a second argument, \%stash, which was the same for the
+    # whole ->request, so you could store data between munges.  Removed, for
+    # now, as YAGNI. -- rjbs, 2019-03-04
+    $self->munge_method_triple($copy);
+
     push @suffixed, $copy;
   }
 
@@ -318,6 +366,8 @@ sub request {
   return $self->_jresponse_from_hresponse($http_res);
 }
 
+sub munge_method_triple {}
+
 sub _jresponse_from_hresponse {
   my ($self, $http_res) = @_;
 
@@ -751,6 +801,9 @@ sub configure_from_client_session {
     }
   }
 
+  $self->_primary_accounts($client_session->{primaryAccounts});
+  $self->_accounts($client_session->{accounts});
+
   return;
 }
 
@@ -807,7 +860,7 @@ JMAP::Tester - a JMAP client made for testing JMAP servers
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 OVERVIEW
 
@@ -888,8 +941,21 @@ The request will effectively be:
 
   [ [ "eatPies", { "a": 100, "c": 3 }, "a" ] ]
 
+=head2 accounts
+
+This is an arrayref of accounts, provided by the client session object.  This
+method will return a list when accounts have been configured.
+
 =head1 METHODS
 
+=head2 primary_account_for
+
+  my $account_id = $tester->primary_account_for($using);
+
+This returns the primary accountId to be used for the given capability, or
+undef if none is available.  This is only useful if the tester has been
+configured from a client session.
+
 =head2 request
 
   my $result = $jtest->request([
@@ -916,6 +982,9 @@ at least, failures are L<JMAP::Tester::Result::Failure> objects.  More refined
 failure objects may exist in the future.  Successful requests return
 L<JMAP::Tester::Response> objects.
 
+Before the JMAP request is made, each triple is passed to a method called
+C<munge_method_triple>, which can tweak the method however it likes.
+
 =head2 upload
 
   my $result = $tester->upload($mime_type, $blob_ref, \%arg);
